Changing Graglorn to Trials

His Dad [05-07-18 - 07:07]
Changing Graglorn to Trials
Filename
HistOffline.lua
data/Craglorn.lua
data/Trials.lua
data/en/en.lua
data/keys.lua
diff --git a/data/Craglorn.lua b/data/Craglorn.lua
deleted file mode 100644
index 51628de..0000000
--- a/data/Craglorn.lua
+++ /dev/null
@@ -1,56 +0,0 @@
-Craglorn_Conqueror = "" -- [1139] = "Craglorn Trials Conqueror" "Complete Hel Ra Citadel, Aetherian Archive, and Sanctum Ophidia at their highest difficulties.",
-
-Craglorn_Dat["N"].id = {
-[991] = {L=1, C=1, key ="11"},		-- "Hel Ra Citadel Completed",  "Defeat the Celestial Warrior, freeing him from the Serpent's control."
-[990] = {L=2, C=1, key ="21"},		-- "Aetherian Archive Completed", "Defeat the Celestial Mage, freeing her from the Serpent's control."
-[1123] ={L=3, C=1, key ="31"},		-- "Sanctum Ophidia Completed", "Defeat the Celestial Serpent."
-[992] = {L=4, C=1, key ="41"},		-- "Dragonstar Arena Champion",  "Conquer all challengers and earn the title of Dragonstar Arena Champion!",
-[1808] ={L=5, C=1, key ="51"},		-- "Halls of Fabrication Completed", "Defeat the Assembly General and assist Divayth Fyr in stopping the flood of animunculi coming from the Halls of Fabrication.",
-[1343] ={L=6, C=1, key ="61"},		-- "Thieves Guild","Drive the dro-m'Athra back to the void and close the Maw of Lorkhaj in Normal Mode.",
-}
-Craglorn_Dat["N"].vet = false
-Craglorn_Dat["N"].key = Craglorn2key["N"]
-
-Craglorn_Dat["V"].id = {
-[1474] = {L=1, C=1, key ="11"},	-- "Hel Ra Citadel Conqueror", "Defeat the Celestial Warrior in Veteran Hel Ra Citadel, while the Trial is scaled to Champion 160."
-[1503] = {L=2, C=1, key ="21"},	-- "Aetherian Archive Conqueror" Defeat the Celestial Mage in Veteran Aetherian Archive, while the Trial is scaled to Champion 160.",
-[1462] = {L=3, C=1, key ="31"},	-- "Sanctum Ophidia Conqueror",
-[870] =  {L=4, C=1, key ="41"},	-- "Hel Ra Citadel: The War Horn", "Sound the war horn in Veteran Hel Ra Citadel and defeat the ancient warriors who answer.",
-[1080] = {L=5, C=1, key ="51"},	-- "Time Trial: Hel Ra Citadel", "Completed the Hel Ra Citadel within a time limit of 33 minutes.",
-[1081] = {L=6, C=1, key ="61"},	-- "Time Trial: Aetherian Archive", "Completed the Aetherian Archive within a time limit of 33 minutes.",
-[1124] = {L=7, C=1, key ="71"},	-- "Time Trial: Sanctum Ophidia", "Completed the Sanctum Ophidia within a time limit of 33 minutes.",
-[1140] = {L=8, C=1, key ="81"},	-- "Dragonstar Arena Conqueror", "Conquer all challengers on the increased difficulty version of Dragonstar Arena.",
-[1810] = {L=9, C=1, key ="91"}, -- "Halls of Fabrication Conqueror", "Defeat the Assembly General in Veteran Halls of Fabrication.",
-[1809] = {L=10, C=1, key ="101"},	-- "Time Trial: Halls of Fabrication", "Complete Veteran Halls of Fabrication within a time limit of 40 minutes. Your trial begins when you enter Abanabi Cave beneath Tel Fyr.",
-[1811] = {L=11, C=1, key ="111"},	-- "Well-Oiled Machine", "Complete Veteran Halls of Fabrication without suffering a group member death.",
-[1831] = {L=12, C=1, key ="112"},	-- "Power House", "Defeat the Pinnacle Factotum without ever using energy from the generator to break a Refabricated Sphere's shield, in Veteran Halls of Fabrication.",
-[1832] = {L=13, C=1, key ="113"},	-- "Planned Obsolescence", ,"Defeat the Refabrication Committee in Veteran Halls of Fabrication without ever allowing the Reclaimer to overcharge a Ruined Factotum.",
-[1833] = {L=14, C=1, key ="114"},	-- "Environmentally Conscious", "Defeat the Assembly General in Veteran Halls of Fabrication without any group member dying to traps and hazards.",
-[1834] = {L=15, C=1, key ="115"}, 	-- "Terminal Terminator", "Defeat the Assembly General in Veteran Halls of Fabrication without letting any Terminals complete their activation sequence.",
-[1839] = {L=16, C=1, key ="116"},	-- "Kill Process", "Defeat one Hunter-Killer Fabricant while the other still has at least half of its health remaining, before defeating the remaining Fabricant in Veteran Halls of Fabrication.",
-[1840] = {L=17, C=1, key ="117"},	-- "Arc-Custodian",, "In Veteran Halls of Fabrication, defeat the Archcustodian using six or fewer Shock Pylons without ever missing an opportunity to disable it with one.",
-[1368] = {L=18, C=1, key ="118"},	-- "Maw of Lorkhaj Conqueror", "Defeat Rakkhat, Fang of Lorkhaj and his legions of dro-m'Athra in Veteran Maw of Lorkhaj.",
-[1367] = {L=19, C=1, key ="119"},	-- "Time Trial: Maw of Lorkhaj", "Complete Veteran Maw of Lorkhaj within a time limit of 40 minutes. Your trial begins when you cross the threshold of the Temple of Seven Riddles.",
-[1369] = {L=20, C=1, key ="120"},	-- "Maw of Lorkhaj: Unchained Ambush", "Use both chain switches within ten seconds in Veteran Maw of Lorkhaj, then defeat the dro-m'Athra invaders.",
-[1386] = {L=21, C=1, key ="121"},	-- "Maw of Lorkhaj: Stainless Souls", "Defeat Rakkhat without anyone dying while afflicted by the Breath of Lorkhaj.",
-[1388] = {L=22, C=1, key ="122"},	-- "Maw of Lorkhaj: Two-Moons Dance", "In Veteran Maw of Lorkhaj, force Rakkhat into his final phase within two lunar cycles, then defeat him.",
-[1389] = {L=23, C=1, key ="123"},	-- "Maw of Lorkhaj: Void Avoided", "Defeat Rakkhat in Veteran Maw of Lorkhaj, with a maximum of two players ever being afflicted by the Breath of Lorkhaj.",
-[1390] = {L=24, C=1, key ="124"},	-- "Maw of Lorkhaj: Fang Focused", "Defeat Rakkhat in Veteran Maw of Lorkhaj, with at least three dro-m'Athra Dreadstalkers still alive.",
-[1391] = {L=25, C=1, key ="125"},	-- "Maw of Lorkhaj: Moons' Champion", "Complete all achievements related to defeating Rakkhat, Fang of Lorkhaj in Veteran Maw of Lorkhaj.",
-[1392] = {L=26, C=1, key ="126"},	-- "Maw of Lorkhaj: Spotless Triumph",, "Complete Veteran Maw of Lorkhaj without suffering a group member death.",
-
-}
-Craglorn_Dat["V"].vet = true
-Craglorn_Dat["V"].key = Craglorn2key["V"]
-
-Craglorn_Dat["VH"].id = {
-[1136] = {L=1, C=1, key ="11"},		-- "Hel Ra Citadel Difficult Mode","Defeat the Celestial Warrior after enraging him through the destruction of his statue army.",
-[1137] = {L=2, C=1, key ="21"},		-- "Aetherian Archive Difficult Mode" "Defeat the Celestial Mage after taunting her by smashing the Aetherial Orbs."
-[1138] = {L=3, C=1, key ="31"},		-- "Sanctum Ophidia Difficult Mode", Defeat the Celestial Serpent after desecrating the sacred banners of the Scaled Court",
-[1829] = {L=4, C=1, key ="41"},		-- "Halls of Fabrication Vanquisher", "Defeat the Assembly General after empowering it by resetting the circuit breaker in Veteran Halls of Fabrication.",
-[1344] = {L=5, C=1, key ="51"},		-- "Thieves Guild:"Maw of Lorkhaj Difficult Mode""Defeat Rakkhat after empowering him at the lunar shrines in Veteran Maw of Lorkhaj.",
-
-}
-
-Craglorn_Dat["VH"].vet = true
-Craglorn_Dat["VH"].key = Craglorn2key["VH"]
diff --git a/data/Trials.lua b/data/Trials.lua
new file mode 100644
index 0000000..302fdbd
--- /dev/null
+++ b/data/Trials.lua
@@ -0,0 +1,57 @@
+Craglorn_Conqueror = "" -- [1139] = "Craglorn Trials Conqueror" "Complete Hel Ra Citadel, Aetherian Archive, and Sanctum Ophidia at their highest difficulties.",
+
+Trials_Dat["N"].id = {
+[991] = {L=1, C=1, key ="11"},		-- "Hel Ra Citadel Completed",  "Defeat the Celestial Warrior, freeing him from the Serpent's control."
+[990] = {L=2, C=1, key ="21"},		-- "Aetherian Archive Completed", "Defeat the Celestial Mage, freeing her from the Serpent's control."
+[1123] ={L=3, C=1, key ="31"},		-- "Sanctum Ophidia Completed", "Defeat the Celestial Serpent."
+[992] = {L=4, C=1, key ="41"},		-- "Dragonstar Arena Champion",  "Conquer all challengers and earn the title of Dragonstar Arena Champion!",
+[1808] ={L=5, C=1, key ="51"},		-- "Halls of Fabrication Completed", "Defeat the Assembly General and assist Divayth Fyr in stopping the flood of animunculi coming from the Halls of Fabrication.",
+[1343] ={L=6, C=1, key ="61"},		-- "Thieves Guild","Drive the dro-m'Athra back to the void and close the Maw of Lorkhaj in Normal Mode.",
+}
+Trials_Dat["N"].vet = false
+Trials_Dat["N"].key = Trials2key["N"]
+
+Trials_Dat["V"].id = {
+[1474] = {L=1, C=1, key ="11"},	-- "Hel Ra Citadel Conqueror", "Defeat the Celestial Warrior in Veteran Hel Ra Citadel, while the Trial is scaled to Champion 160."
+[1503] = {L=2, C=1, key ="21"},	-- "Aetherian Archive Conqueror" Defeat the Celestial Mage in Veteran Aetherian Archive, while the Trial is scaled to Champion 160.",
+[1462] = {L=3, C=1, key ="31"},	-- "Sanctum Ophidia Conqueror",
+[870] =  {L=4, C=1, key ="41"},	-- "Hel Ra Citadel: The War Horn", "Sound the war horn in Veteran Hel Ra Citadel and defeat the ancient warriors who answer.",
+[1080] = {L=5, C=1, key ="51"},	-- "Time Trial: Hel Ra Citadel", "Completed the Hel Ra Citadel within a time limit of 33 minutes.",
+[1081] = {L=6, C=1, key ="61"},	-- "Time Trial: Aetherian Archive", "Completed the Aetherian Archive within a time limit of 33 minutes.",
+[1124] = {L=7, C=1, key ="71"},	-- "Time Trial: Sanctum Ophidia", "Completed the Sanctum Ophidia within a time limit of 33 minutes.",
+[1140] = {L=8, C=1, key ="81"},	-- "Dragonstar Arena Conqueror", "Conquer all challengers on the increased difficulty version of Dragonstar Arena.",
+[1810] = {L=9, C=1, key ="91"}, -- "Halls of Fabrication Conqueror", "Defeat the Assembly General in Veteran Halls of Fabrication.",
+[1809] = {L=10, C=1, key ="101"},	-- "Time Trial: Halls of Fabrication", "Complete Veteran Halls of Fabrication within a time limit of 40 minutes. Your trial begins when you enter Abanabi Cave beneath Tel Fyr.",
+[1811] = {L=11, C=1, key ="111"},	-- "Well-Oiled Machine", "Complete Veteran Halls of Fabrication without suffering a group member death.",
+[1831] = {L=12, C=1, key ="112"},	-- "Power House", "Defeat the Pinnacle Factotum without ever using energy from the generator to break a Refabricated Sphere's shield, in Veteran Halls of Fabrication.",
+[1832] = {L=13, C=1, key ="113"},	-- "Planned Obsolescence", ,"Defeat the Refabrication Committee in Veteran Halls of Fabrication without ever allowing the Reclaimer to overcharge a Ruined Factotum.",
+[1833] = {L=14, C=1, key ="114"},	-- "Environmentally Conscious", "Defeat the Assembly General in Veteran Halls of Fabrication without any group member dying to traps and hazards.",
+[1834] = {L=15, C=1, key ="115"}, 	-- "Terminal Terminator", "Defeat the Assembly General in Veteran Halls of Fabrication without letting any Terminals complete their activation sequence.",
+[1839] = {L=16, C=1, key ="116"},	-- "Kill Process", "Defeat one Hunter-Killer Fabricant while the other still has at least half of its health remaining, before defeating the remaining Fabricant in Veteran Halls of Fabrication.",
+[1840] = {L=17, C=1, key ="117"},	-- "Arc-Custodian",, "In Veteran Halls of Fabrication, defeat the Archcustodian using six or fewer Shock Pylons without ever missing an opportunity to disable it with one.",
+[1368] = {L=18, C=1, key ="118"},	-- "Maw of Lorkhaj Conqueror", "Defeat Rakkhat, Fang of Lorkhaj and his legions of dro-m'Athra in Veteran Maw of Lorkhaj.",
+[1367] = {L=19, C=1, key ="119"},	-- "Time Trial: Maw of Lorkhaj", "Complete Veteran Maw of Lorkhaj within a time limit of 40 minutes. Your trial begins when you cross the threshold of the Temple of Seven Riddles.",
+[1369] = {L=20, C=1, key ="120"},	-- "Maw of Lorkhaj: Unchained Ambush", "Use both chain switches within ten seconds in Veteran Maw of Lorkhaj, then defeat the dro-m'Athra invaders.",
+[1386] = {L=21, C=1, key ="121"},	-- "Maw of Lorkhaj: Stainless Souls", "Defeat Rakkhat without anyone dying while afflicted by the Breath of Lorkhaj.",
+[1388] = {L=22, C=1, key ="122"},	-- "Maw of Lorkhaj: Two-Moons Dance", "In Veteran Maw of Lorkhaj, force Rakkhat into his final phase within two lunar cycles, then defeat him.",
+[1389] = {L=23, C=1, key ="123"},	-- "Maw of Lorkhaj: Void Avoided", "Defeat Rakkhat in Veteran Maw of Lorkhaj, with a maximum of two players ever being afflicted by the Breath of Lorkhaj.",
+[1390] = {L=24, C=1, key ="124"},	-- "Maw of Lorkhaj: Fang Focused", "Defeat Rakkhat in Veteran Maw of Lorkhaj, with at least three dro-m'Athra Dreadstalkers still alive.",
+[1391] = {L=25, C=1, key ="125"},	-- "Maw of Lorkhaj: Moons' Champion", "Complete all achievements related to defeating Rakkhat, Fang of Lorkhaj in Veteran Maw of Lorkhaj.",
+[1392] = {L=26, C=1, key ="126"},	-- "Maw of Lorkhaj: Spotless Triumph",, "Complete Veteran Maw of Lorkhaj without suffering a group member death.",
+
+}
+Trials_Dat["V"].vet = true
+Trials_Dat["V"].key = Trials2key["V"]
+
+Trials_Dat["VH"].id = {
+[1136] = {L=1, C=1, key ="11"},		-- "Hel Ra Citadel Difficult Mode","Defeat the Celestial Warrior after enraging him through the destruction of his statue army.",
+[1137] = {L=2, C=1, key ="21"},		-- "Aetherian Archive Difficult Mode" "Defeat the Celestial Mage after taunting her by smashing the Aetherial Orbs."
+[1138] = {L=3, C=1, key ="31"},		-- "Sanctum Ophidia Difficult Mode", Defeat the Celestial Serpent after desecrating the sacred banners of the Scaled Court",
+[1829] = {L=4, C=1, key ="41"},		-- "Halls of Fabrication Vanquisher", "Defeat the Assembly General after empowering it by resetting the circuit breaker in Veteran Halls of Fabrication.",
+[1344] = {L=5, C=1, key ="51"},		-- "Thieves Guild:"Maw of Lorkhaj Difficult Mode""Defeat Rakkhat after empowering him at the lunar shrines in Veteran Maw of Lorkhaj.",
+[1139] = {L=6, C=1, key ="61"},		-- "Craglorn Trials Conqueror",,"Complete Hel Ra Citadel, Aetherian Archive, and Sanctum Ophidia at their highest difficulties.",
+
+}
+
+Trials_Dat["VH"].vet = true
+Trials_Dat["VH"].key = Trials2key["VH"]
diff --git a/data/en/en.lua b/data/en/en.lua
index 59dc3c0..42b62a1 100644
--- a/data/en/en.lua
+++ b/data/en/en.lua
@@ -115,9 +115,9 @@ L.Grp_TabName["2N"] = "Mode 2N"
 L.Grp_TabName["2V"] = "Mode 2V"
 L.Grp_TabName["2VH"] = "Mode 2VH"

-L.Crag_TabName["N"] = "Craglorn Norm"
-L.Crag_TabName["V"] = "Craglorn Vet"
-L.Crag_TabName["VH"] = "Craglorn Hard"
+L.Crag_TabName["N"] = "Trials Norm"
+L.Crag_TabName["V"] = "Trials Vet"
+L.Crag_TabName["VH"] = "Trials Hard"

 pub_names = {
 --EP
@@ -169,8 +169,8 @@ grp_names = {
 }


-Craglorn_Names= {}
-Craglorn_Names["N"] = {
+Trials_Names= {}
+Trials_Names["N"] = {
 	["11"] = "Craglorn: Hel Ra Citadel Conqueror",
 	["21"] = "Craglorn: Aetherian Archive Conqueror",
 	["31"] = "Craglorn: Sanctum Ophidia Conqueror",
@@ -178,7 +178,7 @@ Craglorn_Names["N"] = {
 	["51"] = "Vvardenfell: Halls of Fabrication Champion",
 	["61"] = "Maw of Lorkhaj Completed"
 }
-Craglorn_Names["V"] = {
+Trials_Names["V"] = {
 	["11"] = "Craglorn: Hel Ra Citadel Completed",
 	["21"] = "Craglorn: Aetherian Archive Completed",
 	["31"] = "Craglorn: Sanctum Ophidia Completed",
@@ -207,12 +207,13 @@ Craglorn_Names["V"] = {
 	["126"] = "Thieves Guild: Maw of Lorkhaj: Spotless Triumph",
 }

-Craglorn_Names["VH"] = {
+Trials_Names["VH"] = {
 	["11"] = "Craglorn: Hel Ra Citadel Difficult Mode",
 	["21"] = "Craglorn: Aetherian Archive Difficult Mode",
 	["31"] = "Craglorn: Sanctum Ophidia Difficult Mode",
 	["41"] = "Vvardenfell: Halls of Fabrication Vanquisher",
 	["51"] = "Thieves Guild: Maw of Lorkhaj Difficult Mode",
+	["61"] = "Craglorn Trials Conqueror",
 }
 Locations = {
 --EP
diff --git a/data/keys.lua b/data/keys.lua
index 97ed3a7..7a65660 100644
--- a/data/keys.lua
+++ b/data/keys.lua
@@ -98,8 +98,8 @@ DLC2key={

 --Craglorn Trials

-Craglorn2key= {}
-Craglorn2key["N"] = {
+Trials2key= {}
+Trials2key["N"] = {
 "11",	-- "Hel Ra Citadel",
 "21",	-- "Aetherian Archive"
 "31",	-- "Sanctum Ophidia",
@@ -108,7 +108,7 @@ Craglorn2key["N"] = {
 "61",	-- "Maw of Lorkhaj Completed"
 }

-Craglorn2key["V"] = {
+Trials2key["V"] = {
 "11",	-- "Hel Ra Citadel",
 "21",	-- "Aetherian Archive"
 "31",	-- "Sanctum Ophidia",
@@ -136,10 +136,11 @@ Craglorn2key["V"] = {
 "125",	-- "Maw of Lorkhaj: Moons' Champion", "Complete all achievements related to defeating Rakkhat, Fang of Lorkhaj in Veteran Maw of Lorkhaj.",
 "126",	-- "Maw of Lorkhaj: Spotless Triumph",, "Complete Veteran Maw of Lorkhaj without suffering a group member death.",
 }
-Craglorn2key["VH"] = {
+Trials2key["VH"] = {
 "11",	-- "Hel Ra Citadel",
 "21",	-- "Aetherian Archive"
 "31",	-- "Sanctum Ophidia",
 "41",	-- "Halls of Fabrication Vanquisher", "Defeat the Assembly General after empowering it by resetting the circuit breaker in Veteran Halls of Fabrication.",
 "51",	-- "Thieves Guild: "Maw of Lorkhaj Difficult Mode"
+"61",	-- "Craglorn Trials Conqueror",,"Complete Hel Ra Citadel, Aetherian Archive, and Sanctum Ophidia at their highest difficulties.",
 }
diff --git a/HistOffline.lua b/HistOffline.lua
index 5fc679c..881ab11 100644
--- a/HistOffline.lua
+++ b/HistOffline.lua
@@ -19,8 +19,8 @@ require( "iuplua" )
 require( "iupluacontrols" )
 iup.SetGlobal("UTF8MODE","YES")
 dofile "../../SavedVariables/History.lua"
-Craglorn_Dat={}
-Craglorn_Order={"N","V","VH"}
+Trials_Dat={}
+Trials_Order={"N","V","VH"}
 Grp_Dat={}

 Grp_Order={"1N","1V","1VH","2N","2V","2VH"}
@@ -30,8 +30,8 @@ Grp2_Order={"2N","2V","2VH"}
 for _,i in ipairs(Grp_Order) do
 	Grp_Dat[i]={}
 end
-for _,i in ipairs(Craglorn_Order) do
-	Craglorn_Dat[i]={}
+for _,i in ipairs(Trials_Order) do
+	Trials_Dat[i]={}
 end

 dofile "./data/Keys.lua"		--Linking tables, must do first
@@ -42,7 +42,7 @@ dofile "./data/Public.lua"
 dofile "./data/Quest.lua"
 dofile "./data/Veteran.lua"		-- Auxillary Achievements for Vet Dungeons
 dofile "./data/WB.lua"
-dofile "./data/Craglorn.lua"
+dofile "./data/Trials.lua"
 dofile "./data/Special.lua"		-- Record of non standard Achievment ID's we need to keep.
 dofile "./data/utility.lua"		-- utility functions

@@ -56,8 +56,8 @@ for _,i in ipairs(Grp_Order) do
 	Grp_Dat[i].reverse_id = reverse_id(Grp_Dat[i].id)
 end

-for _,i in ipairs(Craglorn_Order) do
-	Craglorn_Dat[i].reverse_id = reverse_id(Craglorn_Dat[i].id)
+for _,i in ipairs(Trials_Order) do
+	Trials_Dat[i].reverse_id = reverse_id(Trials_Dat[i].id)
 end

 Pub_Dat.reverse_id = reverse_id(Pub_Dat.id)
@@ -304,7 +304,7 @@ end
   dung.DLC.key = {}

   dung.Grp = {}		-- these ones are indexed.
-  dung.Craglorn = {}
+  dung.Trials = {}

   -- Set up dungeon mode Group Dungeons
   for _,i in ipairs(Grp_Order) do
@@ -358,43 +358,43 @@ end
 	end
   end

-  -- Set up dungeon mode Craglorn Trials
-  for _,i in ipairs(Craglorn_Order) do
-		dung.Craglorn[i]= {}
-		dung.Craglorn[i].key ={}   -- key lookup
-		dung.Craglorn[i].box = iup.matrix {numcol=#accounts[acc].playerIDs,  numlin=_size(Craglorn_Dat[i].id), widthdef=100}
-		iup.SetAttribute(dung.Craglorn[i].box, "READONLY", "YES")
+  -- Set up dungeon mode  Trials
+  for _,i in ipairs(Trials_Order) do
+		dung.Trials[i]= {}
+		dung.Trials[i].key ={}   -- key lookup
+		dung.Trials[i].box = iup.matrix {numcol=#accounts[acc].playerIDs,  numlin=_size(Trials_Dat[i].id), widthdef=100}
+		iup.SetAttribute(dung.Trials[i].box, "READONLY", "YES")

-		dung.Craglorn[i].tab = iup.vbox {
+		dung.Trials[i].tab = iup.vbox {
 							["tabtitle"] =L.Crag_TabName[i],
-							dung.Craglorn[i].box,
+							dung.Trials[i].box,
 							iup.fill{},
 						}

-	dung.Craglorn[i].box.dat = Craglorn_Dat[i]
-	dung.Craglorn[i].box.mousemove_cb = box_mousemove_cb
-	dung.Craglorn[i].box.leavewindow_cb = box_leavewindow_cb
+	dung.Trials[i].box.dat = Trials_Dat[i]
+	dung.Trials[i].box.mousemove_cb = box_mousemove_cb
+	dung.Trials[i].box.leavewindow_cb = box_leavewindow_cb


 	--set lines Heading
-	dung.Craglorn[i].box:setcell(0,0, L.Location)
+	dung.Trials[i].box:setcell(0,0, L.Location)
 	--Set Line titles
-	for line,key in ipairs(Craglorn_Dat[i].key) do
-		dung.Craglorn[i].box:setcell(line, 0, Craglorn_Names[i][key])
+	for line,key in ipairs(Trials_Dat[i].key) do
+		dung.Trials[i].box:setcell(line, 0, Trials_Names[i][key])
 	end

 	--Create Columns for Chars
 	for col ,playerID in ipairs(accounts[acc].playerIDs) do
-		dung.Craglorn[i].box:setcell(0, col, playerNames[playerID])
+		dung.Trials[i].box:setcell(0, col, playerNames[playerID])
 	end



     -- a table for each dungeon to which we add characters
-	for _,key in ipairs(Craglorn2key[i]) do
-	  dung.Craglorn[i].key[key] = {}
+	for _,key in ipairs(Trials2key[i]) do
+	  dung.Trials[i].key[key] = {}
 	  for _,playerID in ipairs(accounts[acc].playerIDs) do
-		dung.Craglorn[i].key[key][playerID] = false
+		dung.Trials[i].key[key][playerID] = false
 	  end
 	end

@@ -525,45 +525,45 @@ end
 			end
 		end

-		-- Create Craglorn Dungeon Boxes ====================================
-		me.Craglorn ={}		-- Put them all together
+		-- Create Trials Dungeon Boxes ====================================
+		me.Trials ={}		-- Put them all together

-		for _, i in ipairs(Craglorn_Order) do		-- For Each Dungeon
-			me.Craglorn[i] = {}						-- Dungeon data storage
-			me.Craglorn[i].vet = Craglorn_Dat[i].vet
-			me.Craglorn[i].box = iup.matrix {numcol=1, numcol_visible=1, numlin=_size(Craglorn_Dat[i].id), widthdef=120}
-			iup.SetAttribute(me.Craglorn[i].box, "READONLY", "YES")
-			me.Craglorn[i].box.dat = Craglorn_Dat[i]		-- for mouseover
-			me.Craglorn[i].box.mousemove_cb = box_mousemove_cb
-			me.Craglorn[i].box.leavewindow_cb = box_leavewindow_cb
+		for _, i in ipairs(Trials_Order) do		-- For Each Dungeon
+			me.Trials[i] = {}						-- Dungeon data storage
+			me.Trials[i].vet = Trials_Dat[i].vet
+			me.Trials[i].box = iup.matrix {numcol=1, numcol_visible=1, numlin=_size(Trials_Dat[i].id), widthdef=120}
+			iup.SetAttribute(me.Trials[i].box, "READONLY", "YES")
+			me.Trials[i].box.dat = Trials_Dat[i]		-- for mouseover
+			me.Trials[i].box.mousemove_cb = box_mousemove_cb
+			me.Trials[i].box.leavewindow_cb = box_leavewindow_cb

 			--Set Column titles in box
-			for line,key in ipairs (Craglorn2key[i]) do  -- Load Dungeons Name. Info LC is the Dungeon Identifier
-					me.Craglorn[i].box:setcell(line,0, Craglorn_Names[i][key])
+			for line,key in ipairs (Trials2key[i]) do  -- Load Dungeons Name. Info LC is the Dungeon Identifier
+					me.Trials[i].box:setcell(line,0, Trials_Names[i][key])
 			end


-			iup.SetAttribute(me.Craglorn[i].box,  "BGCOLOR*:1", BG_Colour_Not_Complete)
-			--iup.SetAttribute(me.Craglorn[i].box,  "FGCOLOR*:1", "DEFAULT")
+			iup.SetAttribute(me.Trials[i].box,  "BGCOLOR*:1", BG_Colour_Not_Complete)
+			--iup.SetAttribute(me.Trials[i].box,  "FGCOLOR*:1", "DEFAULT")
 			-- set text if achievement found and change background
-			for id, Gdat in pairs (Craglorn_Dat[i].id) do
+			for id, Gdat in pairs (Trials_Dat[i].id) do
 				local bgcolour
 				if thischar.ach[id] ~= nil then
 					bgcolour = "BGCOLOR" .. Gdat.L .. ":" .. Gdat.C
-					me.Craglorn[i].box:setcell(Gdat.L,Gdat.C, L.YesLabel)
-					iup.SetAttribute(me.Craglorn[i].box, bgcolour, BG_Colour_Complete)
+					me.Trials[i].box:setcell(Gdat.L,Gdat.C, L.YesLabel)
+					iup.SetAttribute(me.Trials[i].box, bgcolour, BG_Colour_Complete)
 					-- Add char to dungeon
-					dung.Craglorn[i].key[Gdat.key][playerID] = true
+					dung.Trials[i].key[Gdat.key][playerID] = true
 				else
-					me.Craglorn[i].box:setcell(Gdat.L,Gdat.C, L.NoLabel)
+					me.Trials[i].box:setcell(Gdat.L,Gdat.C, L.NoLabel)
 				end

 			end

 			-- Create display tab
-			me.Craglorn[i].tab = iup.vbox {
+			me.Trials[i].tab = iup.vbox {
 						["tabtitle"] =L.Crag_TabName[i],
-						me.Craglorn[i].box,
+						me.Trials[i].box,
 						iup.fill{},
 				}
 		end
@@ -678,7 +678,7 @@ end
 -- Create WorldBoss Achievements Box==========================
 		me.WB_box= iup.matrix {numcol=4, numcol_visible=4,  numlin=5, widthdef=110}

-		for i=1, 4 do  -- Load headings, not craglorn
+		for i=1, 4 do  -- Load headings, not Trials
 			me.WB_box:setcell(0,i, Area_names[i].long)
 		end
 		me.WB_box:setcell(0,0, L.Zone)
@@ -922,11 +922,11 @@ end
 			end
 		end

-		-- All Craglorn Dungeons
-		for _,i in ipairs (Craglorn_Order) do
-			if me.isvet or me.Craglorn[i].vet == false then
+		-- All Trials Dungeons
+		for _,i in ipairs (Trials_Order) do
+			if me.isvet or me.Trials[i].vet == false then
 				-- non vet chars only see non-vet dungeons
-				iup.Append(me.data_tabs, me.Craglorn[i].tab)
+				iup.Append(me.data_tabs, me.Trials[i].tab)
 			end
 		end

@@ -1113,12 +1113,12 @@ iup.Append(accounts[acc].char_tabs, accounts[acc].log_tab)

 	if #accounts[acc].playerIDs_vet > 0  then  -- skip vet and trials if no eligible chars

-		-- Create Craglorn  Tab ============================================
-		for _,i in ipairs (Craglorn_Order) do
-			iup.Append(accounts[acc].dung_tabs, dung.Craglorn[i].tab)
+		-- Create Trials  Tab ============================================
+		for _,i in ipairs (Trials_Order) do
+			iup.Append(accounts[acc].dung_tabs, dung.Trials[i].tab)
 			-- Populate with character data ============================
-		--	print ("populate Craglorn")
-			populate(dung.Craglorn[i], Craglorn_Dat[i].key)
+		--	print ("populate Trials")
+			populate(dung.Trials[i], Trials_Dat[i].key)
 		end
 	end -- has vet chars
